summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorHenri Sara <henri.sara@itmill.com>2009-05-18 10:38:49 +0000
committerHenri Sara <henri.sara@itmill.com>2009-05-18 10:38:49 +0000
commit6a27bd3b0310ebc7b56f18c1cadd33fcda73084d (patch)
tree6a6285492baba8be9cb90b5364caea48025e5864 /src
parent23d2a2df55cfb0830c7d72c131718430f5927e40 (diff)
downloadvaadin-framework-6a27bd3b0310ebc7b56f18c1cadd33fcda73084d.tar.gz
vaadin-framework-6a27bd3b0310ebc7b56f18c1cadd33fcda73084d.zip
Incomplete - task#2904 Toolkit -> Vaadin renames
svn changeset:7850/svn branch:6.0
Diffstat (limited to 'src')
-rw-r--r--src/com/vaadin/Application.java8
-rw-r--r--src/com/vaadin/demo/package.html2
-rw-r--r--src/com/vaadin/demo/sampler/FeatureSet.java2
-rw-r--r--src/com/vaadin/terminal/gwt/client/ApplicationConfiguration.java2
-rw-r--r--src/com/vaadin/terminal/gwt/client/Focusable.java2
-rw-r--r--src/com/vaadin/terminal/gwt/client/ui/TreeAction.java2
-rw-r--r--src/com/vaadin/terminal/gwt/client/ui/VPopupView.java2
-rw-r--r--src/com/vaadin/terminal/gwt/client/ui/VToolkitOverlay.java2
-rw-r--r--src/com/vaadin/terminal/gwt/client/ui/VView.java2
-rw-r--r--src/com/vaadin/terminal/gwt/server/AbstractApplicationServlet.java4
-rw-r--r--src/com/vaadin/terminal/gwt/server/ApplicationRunnerServlet.java2
-rw-r--r--src/com/vaadin/tests/CustomLayoutDemo.java10
-rw-r--r--src/com/vaadin/tests/LayoutDemo.java2
-rw-r--r--src/com/vaadin/tests/PerformanceTestSubTreeCaching.java2
-rw-r--r--src/com/vaadin/tests/QueryContainerDemo.java17
-rw-r--r--src/com/vaadin/tests/RandomLayoutStress.java2
-rw-r--r--src/com/vaadin/tests/TreeFilesystem.java8
-rw-r--r--src/com/vaadin/tests/TreeFilesystemContainer.java15
-rw-r--r--src/com/vaadin/tests/UsingObjectsInSelect.java6
-rw-r--r--src/com/vaadin/tests/featurebrowser/IntroWelcome.java3
-rw-r--r--src/com/vaadin/tests/layouts/DeepComponentTrees.java4
-rw-r--r--src/com/vaadin/tests/tickets/Ticket1362Login.java4
-rw-r--r--src/com/vaadin/ui/CustomLayout.java2
-rw-r--r--src/com/vaadin/ui/LoginForm.java2
-rw-r--r--src/com/vaadin/ui/Window.java11
25 files changed, 57 insertions, 61 deletions
diff --git a/src/com/vaadin/Application.java b/src/com/vaadin/Application.java
index 3cab4a2054..da0a373909 100644
--- a/src/com/vaadin/Application.java
+++ b/src/com/vaadin/Application.java
@@ -35,9 +35,9 @@ import com.vaadin.ui.Window;
/**
* <p>
* Base class required for all Vaadin applications. This class provides all the
- * basic services required by the toolkit. These services allow external
- * discovery and manipulation of the user, {@link com.vaadin.ui.Window windows}
- * and themes, and starting and stopping the application.
+ * basic services required by Vaadin. These services allow external discovery
+ * and manipulation of the user, {@link com.vaadin.ui.Window windows} and
+ * themes, and starting and stopping the application.
* </p>
*
* <p>
@@ -799,7 +799,7 @@ public abstract class Application implements URIHandler,
/**
* Gets the previous user of the application.
*
- * @return the previous Toolkit user, if user has not changed ever on
+ * @return the previous Vaadin user, if user has not changed ever on
* application it returns <code>null</code>
*/
public Object getPreviousUser() {
diff --git a/src/com/vaadin/demo/package.html b/src/com/vaadin/demo/package.html
index 0a6d902e31..38ccd7654a 100644
--- a/src/com/vaadin/demo/package.html
+++ b/src/com/vaadin/demo/package.html
@@ -6,7 +6,7 @@
<body bgcolor="white">
<p>Provides several fully functional Vaadin example applications. These
-highlight certain aspects of the toolkit and how it can be
+highlight certain aspects of the Vaadin and how it can be
used to produce simple, elegant yet powerful user interface driven
applications.</p>
diff --git a/src/com/vaadin/demo/sampler/FeatureSet.java b/src/com/vaadin/demo/sampler/FeatureSet.java
index 80a8e83206..7e60b9a641 100644
--- a/src/com/vaadin/demo/sampler/FeatureSet.java
+++ b/src/com/vaadin/demo/sampler/FeatureSet.java
@@ -399,7 +399,7 @@ public class FeatureSet extends Feature {
super(
"Dates",
"Dates",
- "The DateField component can be used to produce various date and time input fields with different resolutions. The date and time format used with this component is reported to the Toolkit by the browser.",
+ "The DateField component can be used to produce various date and time input fields with different resolutions. The date and time format used with this component is reported to Vaadin by the browser.",
new Feature[] {
//
new DatePopup(), //
diff --git a/src/com/vaadin/terminal/gwt/client/ApplicationConfiguration.java b/src/com/vaadin/terminal/gwt/client/ApplicationConfiguration.java
index 0eb505761b..9fa9e19019 100644
--- a/src/com/vaadin/terminal/gwt/client/ApplicationConfiguration.java
+++ b/src/com/vaadin/terminal/gwt/client/ApplicationConfiguration.java
@@ -99,7 +99,7 @@ public class ApplicationConfiguration {
}
} else {
- $wnd.alert("Toolkit app failed to initialize: " + this.id);
+ $wnd.alert("Vaadin app failed to initialize: " + this.id);
}
}-*/;
diff --git a/src/com/vaadin/terminal/gwt/client/Focusable.java b/src/com/vaadin/terminal/gwt/client/Focusable.java
index bf225ad61d..35f9c1ba76 100644
--- a/src/com/vaadin/terminal/gwt/client/Focusable.java
+++ b/src/com/vaadin/terminal/gwt/client/Focusable.java
@@ -2,7 +2,7 @@ package com.vaadin.terminal.gwt.client;
/**
* GWT's HasFocus is way too overkill for just receiving focus in simple
- * components. Toolkit uses this interface in addition to GWT's HasFocus to pass
+ * components. Vaadin uses this interface in addition to GWT's HasFocus to pass
* focus requests from server to actual ui widgets in browsers.
*
* So in to make your server side focusable component receive focus on client
diff --git a/src/com/vaadin/terminal/gwt/client/ui/TreeAction.java b/src/com/vaadin/terminal/gwt/client/ui/TreeAction.java
index 641b729521..31d2ea749a 100644
--- a/src/com/vaadin/terminal/gwt/client/ui/TreeAction.java
+++ b/src/com/vaadin/terminal/gwt/client/ui/TreeAction.java
@@ -24,7 +24,7 @@ public class TreeAction extends Action {
/**
* Sends message to server that this action has been fired. Messages are
- * "standard" Toolkit messages whose value is comma separated pair of
+ * "standard" Vaadin messages whose value is comma separated pair of
* targetKey (row, treeNod ...) and actions id.
*
* Variablename is always "action".
diff --git a/src/com/vaadin/terminal/gwt/client/ui/VPopupView.java b/src/com/vaadin/terminal/gwt/client/ui/VPopupView.java
index eb0c432464..ce1fa343f3 100644
--- a/src/com/vaadin/terminal/gwt/client/ui/VPopupView.java
+++ b/src/com/vaadin/terminal/gwt/client/ui/VPopupView.java
@@ -314,7 +314,7 @@ public class VPopupView extends HTML implements Container {
/*
*
- * We need a hack make popup act as a child of VPopupView in toolkits
+ * We need a hack make popup act as a child of VPopupView in Vaadin's
* component tree, but work in default GWT manner when closing or
* opening.
*
diff --git a/src/com/vaadin/terminal/gwt/client/ui/VToolkitOverlay.java b/src/com/vaadin/terminal/gwt/client/ui/VToolkitOverlay.java
index 9aeea15536..84b3c78405 100644
--- a/src/com/vaadin/terminal/gwt/client/ui/VToolkitOverlay.java
+++ b/src/com/vaadin/terminal/gwt/client/ui/VToolkitOverlay.java
@@ -14,7 +14,7 @@ import com.google.gwt.user.client.ui.RootPanel;
import com.vaadin.terminal.gwt.client.BrowserInfo;
/**
- * In Toolkit UI this Overlay should always be used for all elements that
+ * In Vaadin UI this Overlay should always be used for all elements that
* temporary float over other components like context menus etc. This is to deal
* stacking order correctly with VWindow objects.
*/
diff --git a/src/com/vaadin/terminal/gwt/client/ui/VView.java b/src/com/vaadin/terminal/gwt/client/ui/VView.java
index b3ed3e9347..08e9e3cf56 100644
--- a/src/com/vaadin/terminal/gwt/client/ui/VView.java
+++ b/src/com/vaadin/terminal/gwt/client/ui/VView.java
@@ -303,7 +303,7 @@ public class VView extends SimplePanel implements Container,
/*
* Two types of Widgets can be focused, either implementing
- * GWT HasFocus of a thinner Toolkit specific Focusable
+ * GWT HasFocus of a thinner Vaadin specific Focusable
* interface.
*/
if (toBeFocused instanceof HasFocus) {
diff --git a/src/com/vaadin/terminal/gwt/server/AbstractApplicationServlet.java b/src/com/vaadin/terminal/gwt/server/AbstractApplicationServlet.java
index aba2c1ba66..716194e618 100644
--- a/src/com/vaadin/terminal/gwt/server/AbstractApplicationServlet.java
+++ b/src/com/vaadin/terminal/gwt/server/AbstractApplicationServlet.java
@@ -407,7 +407,7 @@ public abstract class AbstractApplicationServlet extends HttpServlet {
return;
}
- // Send initial AJAX page that kickstarts Toolkit application
+ // Send initial AJAX page that kickstarts a Vaadin application
writeAjaxPage(request, response, window, themeName, application);
} catch (final SessionExpired e) {
@@ -1204,7 +1204,7 @@ public abstract class AbstractApplicationServlet extends HttpServlet {
// supported, but the hack is make it possible to use linux and
// hosted mode browser for debugging. Note that due this hack,
// debugging gwt code in portals with linux will be problematic if
- // there are multiple toolkit portlets visible at the same time.
+ // there are multiple Vaadin portlets visible at the same time.
// TODO remove this when hosted mode on linux gets newer gecko
page.write("<iframe tabIndex=\"-1\" id=\"__gwt_historyFrame\" "
diff --git a/src/com/vaadin/terminal/gwt/server/ApplicationRunnerServlet.java b/src/com/vaadin/terminal/gwt/server/ApplicationRunnerServlet.java
index fe20093e02..8d0f195c15 100644
--- a/src/com/vaadin/terminal/gwt/server/ApplicationRunnerServlet.java
+++ b/src/com/vaadin/terminal/gwt/server/ApplicationRunnerServlet.java
@@ -93,7 +93,7 @@ public class ApplicationRunnerServlet extends AbstractApplicationServlet {
* <ul>
* <li>context=vaadin</li>
* <li>Runner servlet=run</li>
- * <li>Toolkit application=com.vaadin.demo.Calc</li>
+ * <li>Vaadin application=com.vaadin.demo.Calc</li>
* </ul>
*
* @param request
diff --git a/src/com/vaadin/tests/CustomLayoutDemo.java b/src/com/vaadin/tests/CustomLayoutDemo.java
index df99f145a6..ac0507332b 100644
--- a/src/com/vaadin/tests/CustomLayoutDemo.java
+++ b/src/com/vaadin/tests/CustomLayoutDemo.java
@@ -18,11 +18,11 @@ import com.vaadin.ui.Component.Listener;
/**
* This example demonstrates custom layout. All components created here are
* placed using custom.html file. Custom layouts may be created with any web
- * designer tool such as Dreamweaver. To place Toolkit components into html
- * page, use divs with location tag as an identifier for Toolkit components, see
- * html page (themes/example/layout/custom.html) and source code below. Body
- * panel contents are changed when menu items are clicked. Contents are HTML
- * pages located at themes/example/layout directory.
+ * designer tool such as Dreamweaver. To place Vaadin components into html page,
+ * use divs with location tag as an identifier for Vaadin components, see html
+ * page (themes/example/layout/custom.html) and source code below. Body panel
+ * contents are changed when menu items are clicked. Contents are HTML pages
+ * located at themes/example/layout directory.
*
* @author IT Mill Ltd.
* @since 4.0.0
diff --git a/src/com/vaadin/tests/LayoutDemo.java b/src/com/vaadin/tests/LayoutDemo.java
index cbdc7baf45..cdeeebfa37 100644
--- a/src/com/vaadin/tests/LayoutDemo.java
+++ b/src/com/vaadin/tests/LayoutDemo.java
@@ -16,7 +16,7 @@ import com.vaadin.ui.TabSheet;
import com.vaadin.ui.Window;
/**
- * This example demonstrates layouts. Layouts are populated with sample Toolkit
+ * This example demonstrates layouts. Layouts are populated with sample Vaadin
* UI components.
*
* @author IT Mill Ltd.
diff --git a/src/com/vaadin/tests/PerformanceTestSubTreeCaching.java b/src/com/vaadin/tests/PerformanceTestSubTreeCaching.java
index aeec8176d8..cf03074e56 100644
--- a/src/com/vaadin/tests/PerformanceTestSubTreeCaching.java
+++ b/src/com/vaadin/tests/PerformanceTestSubTreeCaching.java
@@ -22,7 +22,7 @@ public class PerformanceTestSubTreeCaching extends CustomComponent {
private final Label result;
- private static final String DESCRIPTION = "Hyphothesis: Toolkit 4 has major architechtural problem when adding "
+ private static final String DESCRIPTION = "Hypothesis: Toolkit 4 has major architechtural problem when adding "
+ "small incrementall updates to a container which has either a lot or "
+ "some very slow components in it. Toolkit 5 has 'subtree caching' and a"
+ " small amount of logic in containers, so CommunicationManager can assure"
diff --git a/src/com/vaadin/tests/QueryContainerDemo.java b/src/com/vaadin/tests/QueryContainerDemo.java
index cb35e2c938..abd98016cd 100644
--- a/src/com/vaadin/tests/QueryContainerDemo.java
+++ b/src/com/vaadin/tests/QueryContainerDemo.java
@@ -17,21 +17,20 @@ import com.vaadin.ui.Window;
/**
* This example shows how Table, Select and Tree UI components can use
- * Containers. QueryContainer is used to bind SQL table rows into Toolkit UI
+ * Containers. QueryContainer is used to bind SQL table rows into Vaadin UI
* components. Table has few example actions added. Also embedding XHTML through
* Label components is used. Demonstrates: how to create
* <code>com.vaadin.data.Container</code> and set it as datasource to UI
* components <code>com.vaadin.ui.Component.Tree</code>, how to receive
- * ExpandEvent and implement
- * <code>com.vaadin.ui.Tree.ExpandListener</code>, how to use
- * <code>com.vaadin.event.Action</code>.
+ * ExpandEvent and implement <code>com.vaadin.ui.Tree.ExpandListener</code>, how
+ * to use <code>com.vaadin.event.Action</code>.
*
* @author IT Mill Ltd.
* @since 4.0.0
*
*/
-public class QueryContainerDemo extends com.vaadin.Application
- implements Action.Handler {
+public class QueryContainerDemo extends com.vaadin.Application implements
+ Action.Handler {
private static final String ACTION_DESCRIPTION = "Try right mouse button to initiate "
+ "actions menu.<br />Note: on Opera you use meta key "
@@ -116,7 +115,7 @@ public class QueryContainerDemo extends com.vaadin.Application
table.addActionHandler(this);
table.setDescription(ACTION_DESCRIPTION);
- // populate Toolkit table component with test SQL table rows
+ // populate Vaadin table component with test SQL table rows
try {
final QueryContainer qc = new QueryContainer(
"SELECT * FROM employee", sampleDatabase.getConnection());
@@ -139,7 +138,7 @@ public class QueryContainerDemo extends com.vaadin.Application
select.setCaption("All distinct units from employee table.");
select.setItemCaptionPropertyId("UNIT");
- // populate Toolkit select component with test SQL table rows
+ // populate Vaadin select component with test SQL table rows
try {
final QueryContainer qc = new QueryContainer(
"SELECT DISTINCT UNIT FROM employee", sampleDatabase
@@ -167,7 +166,7 @@ public class QueryContainerDemo extends com.vaadin.Application
+ "actions menu. Note: on Opera you use meta key "
+ "and left mouse button.");
- // Populate Toolkit Tree using select component as data source
+ // Populate Vaadin Tree using select component as data source
tree.setContainerDataSource(select.getContainerDataSource());
}
diff --git a/src/com/vaadin/tests/RandomLayoutStress.java b/src/com/vaadin/tests/RandomLayoutStress.java
index 5bfff45a3a..a6277a8262 100644
--- a/src/com/vaadin/tests/RandomLayoutStress.java
+++ b/src/com/vaadin/tests/RandomLayoutStress.java
@@ -23,7 +23,7 @@ import com.vaadin.ui.TextField;
import com.vaadin.ui.Window;
/**
- * This example demonstrates layouts. Layouts are populated with sample Toolkit
+ * This example demonstrates layouts. Layouts are populated with sample Vaadin
* UI components.
*
* @author IT Mill Ltd.
diff --git a/src/com/vaadin/tests/TreeFilesystem.java b/src/com/vaadin/tests/TreeFilesystem.java
index 4291498c02..202338cd50 100644
--- a/src/com/vaadin/tests/TreeFilesystem.java
+++ b/src/com/vaadin/tests/TreeFilesystem.java
@@ -15,10 +15,10 @@ import com.vaadin.ui.Window;
import com.vaadin.ui.Tree.ExpandEvent;
/**
- * Browsable file explorer using Toolkit Tree component. Demonstrates: how to
- * add items hierarchially into
- * <code>com.vaadin.ui.Component.Tree</code>, how to receive ExpandEvent
- * and implement <code>com.vaadin.ui.Tree.ExpandListener</code>.
+ * Browsable file explorer using Vaadin Tree component. Demonstrates: how to add
+ * items hierarchically into <code>com.vaadin.ui.Component.Tree</code>, how to
+ * receive ExpandEvent and implement
+ * <code>com.vaadin.ui.Tree.ExpandListener</code>.
*
* @since 4.0.0
*
diff --git a/src/com/vaadin/tests/TreeFilesystemContainer.java b/src/com/vaadin/tests/TreeFilesystemContainer.java
index dc56f687dc..52154fbe22 100644
--- a/src/com/vaadin/tests/TreeFilesystemContainer.java
+++ b/src/com/vaadin/tests/TreeFilesystemContainer.java
@@ -19,18 +19,17 @@ import com.vaadin.ui.Component.Event;
import com.vaadin.ui.Component.Listener;
/**
- * Browsable file explorer using Toolkit Tree component. Demonstrates: how to
- * use <code>com.vaadin.ui.Component.Tree</code> datasource container,
- * how to create <code>com.vaadin.data.util.FilesystemContainer</code>,
- * how to read <code>com.vaadin.ui.Component.Event</code> objects, how
- * to receive and handle any event by implementing
- * <code>com.vaadin.ui.Component.Listener</code>.
+ * Browsable file explorer using Vaadin Tree component. Demonstrates: how to use
+ * <code>com.vaadin.ui.Component.Tree</code> datasource container, how to create
+ * <code>com.vaadin.data.util.FilesystemContainer</code>, how to read
+ * <code>com.vaadin.ui.Component.Event</code> objects, how to receive and handle
+ * any event by implementing <code>com.vaadin.ui.Component.Listener</code>.
*
* @since 4.0.0
*
*/
-public class TreeFilesystemContainer extends com.vaadin.Application
- implements Listener {
+public class TreeFilesystemContainer extends com.vaadin.Application implements
+ Listener {
// Filesystem explorer panel and it's components
private final Panel explorerPanel = new Panel("Filesystem explorer");
diff --git a/src/com/vaadin/tests/UsingObjectsInSelect.java b/src/com/vaadin/tests/UsingObjectsInSelect.java
index 6a608f17f3..2fc0fc5eac 100644
--- a/src/com/vaadin/tests/UsingObjectsInSelect.java
+++ b/src/com/vaadin/tests/UsingObjectsInSelect.java
@@ -14,8 +14,8 @@ import com.vaadin.ui.Panel;
import com.vaadin.ui.Select;
import com.vaadin.ui.Window;
-public class UsingObjectsInSelect extends com.vaadin.Application
- implements ValueChangeListener {
+public class UsingObjectsInSelect extends com.vaadin.Application implements
+ ValueChangeListener {
private final Select select = new Select();
private final Label selectedTask = new Label("Selected task",
@@ -67,7 +67,7 @@ public class UsingObjectsInSelect extends com.vaadin.Application
}
/**
- * Sample class which is bind in Toolkit components
+ * Sample class which is bound to Vaadin components
*
*/
public class Task {
diff --git a/src/com/vaadin/tests/featurebrowser/IntroWelcome.java b/src/com/vaadin/tests/featurebrowser/IntroWelcome.java
index cffb4c7994..d9c20b96b2 100644
--- a/src/com/vaadin/tests/featurebrowser/IntroWelcome.java
+++ b/src/com/vaadin/tests/featurebrowser/IntroWelcome.java
@@ -53,8 +53,7 @@ public class IntroWelcome extends Feature implements URIHandler,
// TODO Add browser agent string
private final String description = WELCOME_TEXT_LOWER
- + "<br /><br />Vaadin Toolkit version: "
- + ApplicationServlet.VERSION;
+ + "<br /><br />Vaadin version: " + ApplicationServlet.VERSION;
public IntroWelcome() {
super();
diff --git a/src/com/vaadin/tests/layouts/DeepComponentTrees.java b/src/com/vaadin/tests/layouts/DeepComponentTrees.java
index 7ee89b35db..e13cdf5c3a 100644
--- a/src/com/vaadin/tests/layouts/DeepComponentTrees.java
+++ b/src/com/vaadin/tests/layouts/DeepComponentTrees.java
@@ -18,7 +18,7 @@ public class DeepComponentTrees extends TestBase {
@Override
protected String getDescription() {
- return "Toolkit should not choke on deep component trees. 15 levels should be minimum to survive.";
+ return "Vaadin should not choke on deep component trees. 15 levels should be minimum to survive.";
}
@Override
@@ -89,7 +89,7 @@ public class DeepComponentTrees extends TestBase {
layout = lo;
}
layout.addComponent(new Label(
- "FF did it! Toolkit, Mozilla and you win! Dare to try again?"));
+ "FF did it! Vaadin, Mozilla and you win! Dare to try again?"));
root.setLayout(r);
}
diff --git a/src/com/vaadin/ui/CustomLayout.java b/src/com/vaadin/ui/CustomLayout.java
index 3b923e5d08..d0d70fcc16 100644
--- a/src/com/vaadin/ui/CustomLayout.java
+++ b/src/com/vaadin/ui/CustomLayout.java
@@ -17,7 +17,7 @@ import com.vaadin.terminal.PaintTarget;
* <p>
* A container component with freely designed layout and style. The layout
* consists of items with textually represented locations. Each item contains
- * one sub-component, which can be any Toolkit component, such as a layout. The
+ * one sub-component, which can be any Vaadin component, such as a layout. The
* adapter and theme are responsible for rendering the layout with a given style
* by placing the items in the defined locations.
* </p>
diff --git a/src/com/vaadin/ui/LoginForm.java b/src/com/vaadin/ui/LoginForm.java
index f8f00170c5..243ac99169 100644
--- a/src/com/vaadin/ui/LoginForm.java
+++ b/src/com/vaadin/ui/LoginForm.java
@@ -16,7 +16,7 @@ import com.vaadin.terminal.URIHandler;
import com.vaadin.terminal.gwt.server.AbstractApplicationServlet;
/**
- * LoginForm is a Toolkit component to handle common problem among Ajax
+ * LoginForm is a Vaadin component to handle common problem among Ajax
* applications: browsers password managers don't fill dynamically created forms
* like all those UI elements created by Vaadin.
* <p>
diff --git a/src/com/vaadin/ui/Window.java b/src/com/vaadin/ui/Window.java
index 90b761652c..a46de06635 100644
--- a/src/com/vaadin/ui/Window.java
+++ b/src/com/vaadin/ui/Window.java
@@ -708,11 +708,10 @@ public class Window extends Panel implements URIHandler, ParameterHandler {
*
* <p>
* This method should not be invoked directly. Instead the
- * {@link com.vaadin.Application#addWindow(Window)} method should be
- * used to add the window to an application and
- * {@link com.vaadin.Application#removeWindow(Window)} method for
- * removing the window from the applicion. These methods call this method
- * implicitly.
+ * {@link com.vaadin.Application#addWindow(Window)} method should be used to
+ * add the window to an application and
+ * {@link com.vaadin.Application#removeWindow(Window)} method for removing
+ * the window from the applicion. These methods call this method implicitly.
* </p>
*
* <p>
@@ -1335,7 +1334,7 @@ public class Window extends Panel implements URIHandler, ParameterHandler {
* in client too. Not the one that is rendered last (the case we'd get if
* implemented in Focusable only).
*
- * To focus component from Toolkit application, use Focusable.focus(). See
+ * To focus component from Vaadin application, use Focusable.focus(). See
* {@link Focusable}.
*
* @param focusable
diff --git a/src/com/vaadin/tests/tickets/Ticket1362Login.java b/src/com/vaadin/tests/tickets/Ticket1362Login.java
index e6ed473285..e876ae4808 100644
--- a/src/com/vaadin/tests/tickets/Ticket1362Login.java
+++ b/src/com/vaadin/tests/tickets/Ticket1362Login.java
@@ -32,7 +32,7 @@ import com.vaadin.ui.Window.Notification;
*
* TODO theme
*
* TODO refine docs, make LoginBox a standard toolkit component
*
* TODO article
*
@@ -53,7 +53,7 @@ public class Ticket1362Login extends Application {
+ "<body onload='setTarget();'>"
+ "Iframe generated by LoginBox. PW managers can autofill form. Form handled by LoginBox "
+ "that will fire LoginEvents. Will post into another iframe, from where the script "
- + "will find toolkit client that will be force synced. <form id='loginf' target='logintarget'>"
+ + "will find Vaadin client that will be force synced. <form id='loginf' target='logintarget'>"
+ "Username : <input type='text' name='username'>"
+ "Password : <input type='password' name='password'>"
+ "<input type='submit' value='login'>" + "</form>"
@@ -32,7 +32,7 @@ import com.vaadin.ui.Window.Notification;
* TODO theme
*
- * TODO refine docs, make LoginBox a standard toolkit component
+ * TODO refine docs, make LoginBox a standard Vaadin component
*
* TODO article